# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MetroErrorErrorMessage(str, Enum):
    """
    MetroErrorErrorMessage
    """

    """
    allowed enum values
    """
    UNAUTHORIZED = 'Unauthorized'
    INVALID_QUERY_PARAMETER = 'Invalid Query Parameter'
    INVALID_PATH_PARAMETER = 'Invalid Path Parameter'
    INVALID_QUERY_OR_PATH_PARAMETER = 'Invalid Query or Path Parameter'
    INTERNAL_SERVER_ERROR = 'Internal Server Error'
    METRO_NOT_FOUND = 'Metro Not Found'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MetroErrorErrorMessage from a JSON string"""
        return cls(json.loads(json_str))


