# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.ssh_key_create_input import SSHKeyCreateInput

class TestSSHKeyCreateInput(unittest.TestCase):
    """SSHKeyCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SSHKeyCreateInput:
        """Test SSHKeyCreateInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SSHKeyCreateInput`
        """
        model = SSHKeyCreateInput()
        if include_optional:
            return SSHKeyCreateInput(
                href = '',
                instances_ids = [
                    ''
                    ],
                key = '',
                label = '',
                tags = [
                    ''
                    ]
            )
        else:
            return SSHKeyCreateInput(
        )
        """

    def testSSHKeyCreateInput(self):
        """Test SSHKeyCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
