# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PortPhysicalPortsType(str, Enum):
    """
    Physical Ports Type
    """

    """
    allowed enum values
    """
    ENUM_1000_BASE_LX = '1000BASE_LX'
    ENUM_10_GBASE_LR = '10GBASE_LR'
    ENUM_100_GBASE_LR4 = '100GBASE_LR4'
    ENUM_10_GBASE_ER = '10GBASE_ER'
    ENUM_1000_BASE_SX = '1000BASE_SX'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PortPhysicalPortsType from a JSON string"""
        return cls(json.loads(json_str))


