# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PtpAdvanceConfigurationLogSyncInterval(int, Enum):
    """
    Logarithmic value that controls the rate of PTP Sync packets. Default is -4 (16 packets per second), Unit packets/second..
    """

    """
    allowed enum values
    """
    NUMBER_MINUS_5 = -5
    NUMBER_MINUS_4 = -4
    NUMBER_MINUS_3 = -3
    NUMBER_MINUS_2 = -2
    NUMBER_MINUS_1 = -1
    NUMBER_0 = 0
    NUMBER_1 = 1

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PtpAdvanceConfigurationLogSyncInterval from a JSON string"""
        return cls(json.loads(json_str))


