# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class RouteFilterState(str, Enum):
    """
    Route Filter status
    """

    """
    allowed enum values
    """
    PROVISIONING = 'PROVISIONING'
    REPROVISIONING = 'REPROVISIONING'
    DEPROVISIONING = 'DEPROVISIONING'
    PROVISIONED = 'PROVISIONED'
    DEPROVISIONED = 'DEPROVISIONED'
    NOT_PROVISIONED = 'NOT_PROVISIONED'
    NOT_DEPROVISIONED = 'NOT_DEPROVISIONED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RouteFilterState from a JSON string"""
        return cls(json.loads(json_str))


