# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class CloudRouterActionType(str, Enum):
    """
    Cloud router action type
    """

    """
    allowed enum values
    """
    BGP_SESSION_STATUS_UPDATE = 'BGP_SESSION_STATUS_UPDATE'
    ROUTE_TABLE_ENTRY_UPDATE = 'ROUTE_TABLE_ENTRY_UPDATE'
    RECEIVED_ROUTE_ENTRY_UPDATE = 'RECEIVED_ROUTE_ENTRY_UPDATE'
    ADVERTISED_ROUTE_ENTRY_UPDATE = 'ADVERTISED_ROUTE_ENTRY_UPDATE'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CloudRouterActionType from a JSON string"""
        return cls(json.loads(json_str))


