# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ExpressionOperator(str, Enum):
    """
    ExpressionOperator
    """

    """
    allowed enum values
    """
    EQUAL = '='
    EXCLAMATION_EQUAL = '!='
    GREATER_THAN = '>'
    GREATER_THAN_EQUAL = '>='
    LESS_THAN = '<'
    LESS_THAN_EQUAL = '<='
    BETWEEN = 'BETWEEN'
    NOT_BETWEEN = 'NOT BETWEEN'
    LIKE = 'LIKE'
    NOT_LIKE = 'NOT LIKE'
    IN = 'IN'
    NOT_IN = 'NOT IN'
    IS_NOT_NULL = 'IS NOT NULL'
    IS_NULL = 'IS NULL'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ExpressionOperator from a JSON string"""
        return cls(json.loads(json_str))


