# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.vrf_bgp_neighbors_list import VrfBGPNeighborsList

class TestVrfBGPNeighborsList(unittest.TestCase):
    """VrfBGPNeighborsList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VrfBGPNeighborsList:
        """Test VrfBGPNeighborsList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VrfBGPNeighborsList`
        """
        model = VrfBGPNeighborsList()
        if include_optional:
            return VrfBGPNeighborsList(
                bgp_neighbors = [
                    equinix.services.metalv1.models.vrf_bgp_neighbors.VrfBGPNeighbors(
                        href = '', 
                        peer_as = 65000, 
                        peer_ip = '8.8.8.8', 
                        state = 'up', )
                    ],
                href = ''
            )
        else:
            return VrfBGPNeighborsList(
        )
        """

    def testVrfBGPNeighborsList(self):
        """Test VrfBGPNeighborsList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
