# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ProductType(str, Enum):
    """
    Product type
    """

    """
    allowed enum values
    """
    VIRTUAL_CONNECTION_PRODUCT = 'VIRTUAL_CONNECTION_PRODUCT'
    IP_BLOCK_PRODUCT = 'IP_BLOCK_PRODUCT'
    VIRTUAL_PORT_PRODUCT = 'VIRTUAL_PORT_PRODUCT'
    CLOUD_ROUTER_PRODUCT = 'CLOUD_ROUTER_PRODUCT'
    PRECISION_TIME_PRODUCT = 'PRECISION_TIME_PRODUCT'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ProductType from a JSON string"""
        return cls(json.loads(json_str))


