# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BGPActions(str, Enum):
    """
    BGP action type
    """

    """
    allowed enum values
    """
    CLEAR_BGPIPV4 = 'CLEAR_BGPIPV4'
    CLEAR_BGPIPV6 = 'CLEAR_BGPIPV6'
    CLEAR_BGPIPV4_INBOUND = 'CLEAR_BGPIPV4_INBOUND'
    CLEAR_BGPIPV6_INBOUND = 'CLEAR_BGPIPV6_INBOUND'
    RESET_BGPIPV4 = 'RESET_BGPIPV4'
    RESET_BGPIPV6 = 'RESET_BGPIPV6'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BGPActions from a JSON string"""
        return cls(json.loads(json_str))


