# coding: utf-8

"""
    Equinix Fabric API v4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class VirtualConnectionPriceConnectionType(str, Enum):
    """
    Virtual Connection type
    """

    """
    allowed enum values
    """
    EVPL_VC = 'EVPL_VC'
    EPL_VC = 'EPL_VC'
    EC_VC = 'EC_VC'
    IP_VC = 'IP_VC'
    VD_CHAIN_VC = 'VD_CHAIN_VC'
    ACCESS_EPL_VC = 'ACCESS_EPL_VC'
    EVPLAN_VC = 'EVPLAN_VC'
    EPLAN_VC = 'EPLAN_VC'
    IPWAN_VC = 'IPWAN_VC'
    IA_VC = 'IA_VC'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of VirtualConnectionPriceConnectionType from a JSON string"""
        return cls(json.loads(json_str))


